@@ -72,9 +72,9 @@
 //! [issues]: https://github.com/cakekindel/slack-blocks-rs/issues/
 //! [Conventional Commits]: https://www.conventionalcommits.org/en/v1.0.0/
 
-#![doc(html_root_url = "https://docs.rs/slack-blocks/0.24.4")]
+#![doc(html_root_url = "https://docs.rs/slack-blocks/0.25.0")]
 #![cfg_attr(docsrs, feature(doc_cfg))]
-#![cfg_attr(docsrs, feature(intra_rustdoc_links))]
+// #![feature(doc_cfg)] // for local docs
 #![deny(missing_docs)]
 #![cfg_attr(not(test),
             forbid(missing_copy_implementations,
@@ -91,11 +91,8 @@ extern crate validator_derive;
 #[cfg_attr(docsrs, doc(cfg(feature = "blox")))]
 pub mod blox;
 
-#[doc(inline)]
 pub mod blocks;
-#[doc(inline)]
 pub mod compose;
-#[doc(inline)]
 pub mod elems;
 
 mod build;
